----------------------------------------------------------------------------------
--      __  ____                 _   __                
--    /  |/  (_)_____________  / | / /___ _   ______ _
--   / /|_/ / / ___/ ___/ __ \/  |/ / __ \ | / / __ `/
--  / /  / / / /__/ /  / /_/ / /|  / /_/ / |/ / /_/ / 
-- /_/  /_/_/\___/_/   \____/_/ |_/\____/|___/\__,_/  
--                                                  
-- Copyright (c) 2019 MicroNova, LLC
-- www.micro-nova.com
--
-- Engineer: Jeremy Bowers
-- Create Date: 12/02/2019
-- Design Name: Logic Gates
-- Target Devices: Mercury 2
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.all;
use IEEE.NUMERIC_STD.all;

entity gates4_top is
  port(
    -- Inputs
    clk     : in std_logic;                             -- Mercury 2 clock
    sw      : in std_logic_vector(3 downto 0);          -- switches for gates4
    -- Outputs
    an_7seg : out std_logic_vector(3 downto 0);         -- Ancode for 7seg disp
    ag_seg  : out std_logic_vector(6 downto 0);         -- Segments a thru g
    seg_dot : out std_logic                             -- decimal point
  );
end gates4_top;

architecture gates4_top of gates4_top is

component sev_seg is
  port(
    -- Group1 - Inputs for the 7 segment logic
    clk_50mhz   : in std_logic;                         -- 50 MHz clock
    ze          : in std_logic_vector(3 downto 0);      -- gates4 results
    
    -- Group2 - Outputs to the baseboard 7 segment display
    ag_segments : out std_logic_vector(6 downto 0);     -- 7SEG_A through 7SEG_G.
    an          : out std_logic_vector(3 downto 0);     -- an selects the target
    dp          : out std_logic                         -- 7 segment display.
                                                        -- dp refers to 7SEG_DOT.
  );
end component;

component gates4 is
  port(
    x : in std_logic_vector(3 downto 0);                -- SW0 through SW3
    z : out std_logic_vector(3 downto 0)                -- result
  );
end component;

-- This signal is the middleman for results
signal z : std_logic_vector(3 downto 0) := (others => '0');

begin                                                   -- mapping to IO pins

    X1: sev_seg port map(
          ze          => z,
          clk_50mhz   => clk,
          ag_segments => ag_seg,
          an          => an_7seg,
          dp          => seg_dot
        );
        
    X2: gates4 port map(
          x           => sw,
          z           => z
        );
        
end gates4_top;
